@@ -266,6 +266,26 @@ def test_get_on_time_performance_export():
     assert sent_req.querystring["useServiceDates"] == ["false"]
     assert sent_req.querystring["onlyFirstStopOfTrip"] == ["true"]
 
+    df = client.get_on_time_performance_export(
+        start_date=target_date,
+        end_date=target_date,
+        route="NC2010",
+    )
+    assert (
+        df[df["trip_id"] == "15141675-NC2010-NCTD-Weekday-06"].iloc[0].block_id == 30102
+    )
+    assert (
+        df[df["trip_id"] == "15141699-NC2010-NCTD-Weekday-06"].iloc[0].block_id == 30106
+    )
+    assert (
+        df[df["trip_id"] == "15141691-NC2010-NCTD-Weekday-06"].iloc[0].block_id == 30104
+    )
+
+    sent_req = httpretty.last_request()
+    assert sent_req.querystring["startDate"] == ["12-21-2020"]
+    assert sent_req.querystring["endDate"] == ["12-21-2020"]
+    assert sent_req.querystring["route"] == ["NC2010"]
+
 
 @httpretty.activate
 def test_get_trip_observations_export():
@@ -569,3 +589,96 @@ def test_get_gps_playback():
     assert sent_req.querystring["beginTime"] == ["07:50"]
     assert sent_req.querystring["endTime"] == ["08:20"]
     assert sent_req.querystring["vehicle"] == ["1410"]
+
+
+def test_format_url():
+    agency = "test_agency"
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    assert client._format_url(client.ARRIVAL_DEPARTURE_OBSERVATIONS) == (
+        SwiftlyAPIClient.PROD_BASE_URL + "/otp/test_agency/arrivals-departures"
+    )
+
+    assert client._format_url(
+        client.RUN_TIMES_BY_ROUTE,
+        route_short_name="test_route",
+    ) == (
+        SwiftlyAPIClient.PROD_BASE_URL
+        + "/run-times/test_agency/route/test_route/by-trip"
+    )
+
+
+@httpretty.activate
+def test_get_routes():
+    agency = "test_agency"
+    client = SwiftlyAPIClient(agency_key=agency, api_key="test_api_key")
+
+    mock_url = client._format_url(client.ROUTES)
+
+    httpretty.register_uri(
+        httpretty.GET,
+        mock_url,
+        responses=[
+            httpretty.Response(
+                body="""
+                    {
+                      "data": {
+                        "agencyKey": "sfmta",
+                        "routes": [
+                          {
+                            "id": "13228",
+                            "longName": "Judah",
+                            "name": "N - Judah",
+                            "shortName": "N",
+                            "type": "0"
+                          },
+                          {
+                            "id": "13221",
+                            "longName": "Embarcadero",
+                            "name": "Embarcadero",
+                            "shortName": "E",
+                            "type": "0"
+                          },
+                          {
+                            "id": "13222",
+                            "longName": "Market & Wharves",
+                            "name": "F - Market & Wharves",
+                            "shortName": "F",
+                            "type": "0"
+                          }
+                        ]
+                      },
+                      "route": "/info/sfmta/routes GET",
+                      "success": true
+                    }
+                    """,
+                status=200,
+            ),
+        ],
+    )
+
+    routes = client.get_routes()
+
+    assert routes == [
+        {
+            "id": "13228",
+            "longName": "Judah",
+            "name": "N - Judah",
+            "shortName": "N",
+            "type": "0",
+        },
+        {
+            "id": "13221",
+            "longName": "Embarcadero",
+            "name": "Embarcadero",
+            "shortName": "E",
+            "type": "0",
+        },
+        {
+            "id": "13222",
+            "longName": "Market & Wharves",
+            "name": "F - Market & Wharves",
+            "shortName": "F",
+            "type": "0",
+        },
+    ]
